################################################################################
#
# Copyright 2014
# Author Imran Shakir
#
# All rights reserved. This program and the accompanying materials
# are made available under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#
# Contributors:
# Imran Shakir - initial implementation
#
################################################################################
require 'spec_helper'

require 'iib/node'

NODE_NAME = "IIB_RUBY_TEST_NODE"

describe 'getting all local integration nodes' do

  it 'should return an empty array when there are no nodes' do
    node = IIB::Node.new(name: NODE_NAME)
    node.stop
    IIB::Node.delete_local_node(NODE_NAME)

    expect(IIB::Node.get_all_local_nodes).to be_empty

    IIB::Node.create_local_node(NODE_NAME)
    node.start
  end

  it 'should have one created integration node' do
    created_node = IIB::Node.new(name: NODE_NAME)
    expect(IIB::Node.get_all_local_nodes).to include(created_node)
  end
  
end

describe 'local integration node' do

  it 'has a name' do
    node = IIB::Node.new(name: NODE_NAME)
    expect(node.name).to eq(NODE_NAME)
  end

  # it 'has a port' do
  #   node = IIB::Node.new(name: NODE_NAME)
  # end

  it 'can be stopped and started' do
    node = IIB::Node.new(name: NODE_NAME)
    node.stop
    node.start
  end

  it 'can be running' do
    node = IIB::Node.new(name: NODE_NAME)
    expect(node.is_running).to be true
  end

  it 'can be not running' do
    node = IIB::Node.new(name: NODE_NAME)
    node.stop
    expect(node.is_running).to be false
    node.start
  end

end

describe 'remote integration node' do

  # it 'has a name' do
  #   node = IIB::Node.new(hostname: 'localhost', port: 4414)
  #   expect(node.name).to eq(NODE_NAME)
  # end

  it 'has a port' do
    node = IIB::Node.new(hostname: 'localhost', port: 4414)
    expect(node.port).to eq(4414)
  end

  it 'cannot be started' do
    node = IIB::Node.new(hostname: 'localhost', port: 4414)
    expect{node.start}.to raise_error(RuntimeError)
  end

  it 'cannot be stopped' do
    node = IIB::Node.new(hostname: 'localhost', port: 4414)
    expect{node.stop}.to raise_error(RuntimeError)
  end

end

describe 'creating local integration nodes' do

  it 'should return an IIB::Node object with the correct name' do
    node_name    = "IIB_RUBY_CREATE_TEST_NODE"
    created_node = IIB::Node.create_local_node(node_name)

    expect(created_node.name).to equal(node_name)
    IIB::Node.delete_local_node(node_name)
  end

end

describe 'deleting local integration nodes' do

  it 'should correctly delete a created node' do
    node_name = "IIB_RUBY_DELETE_TEST_NODE"
    IIB::Node.create_local_node(node_name)
    IIB::Node.delete_local_node(node_name)
    expect(IIB::Node.get_all_local_nodes.size).to eq(1)
  end

end

describe 'equals on integration nodes' do

  it 'should equal if two local nodes have the same name' do
    node_name = "RUBY_TEST_EQUALS_NODE"
    node_one = IIB::Node.new(name: node_name)
    node_two = IIB::Node.new(name: node_name)
    expect(node_one).to eq(node_two)
  end

end